import { IVpc } from 'aws-cdk-lib/aws-ec2';
import { Cluster, KubernetesManifest, KubernetesVersion, ICluster } from 'aws-cdk-lib/aws-eks';
import { IRole } from 'aws-cdk-lib/aws-iam';
import { Construct } from 'constructs';
/**
 * @internal
 * Take the path of the ALB IAM policy and modify it with VPC ARN
 * @param scope the CDK scope to create resources in
 * @param filepath the path containing the IAM policy definition in JSON
 * @param vpc the VPC of the EKS cluster
 * @return a json object containing the IAM policy
 */
export declare function setupAlbControllerIamPolicy(scope: Construct, filepath: string, vpc: IVpc): any;
/**
 * @internal
 * Configure the EBS CSI driver on an Amazon EKS cluster
 * @param scope the CDK scope to create resources in
 * @param cluster the EKS cluster to install the CSI driver in
 * @param eksClusterK8sVersion the Kubernetes version of the EKS cluster
 * @return the IAM role used by the CSI driver
 */
export declare function ebsCsiDriverSetup(scope: Construct, cluster: ICluster, eksClusterK8sVersion: KubernetesVersion): IRole;
/**
 * @internal
 * Configure the IAM role used by the aws-node pod following AWS best practice not to use the EC2 instance role
 * @param scope the CDK scope to create resources in
 * @param cluster the EKS cluster to configure the aws-node pod in
 * @return the IAM role used by the aws-node pod
 */
export declare function awsNodeRoleSetup(scope: Construct, cluster: ICluster): IRole;
/**
 * @internal
 * Method to setup a managed nodegroup to bootstrap all cluster vital componenets like
 * core dns, karpenter, ebs csi driver.
 * @param scope the CDK scope to create the nodegroup in
 * @param cluster the EKS cluster to create the nodegroup in
 * @param nodeRole the IAM role to use for the nodegroup
 */
export declare function toolingManagedNodegroupSetup(scope: Construct, cluster: Cluster, nodeRole: IRole): void;
/**
 * @internal
 * Create a namespace with a predefined baseline
 *  * Create namespace
 *  * Define a Network Policy
 * @param cluster the EKS cluster to create the namespace in
 * @param namespace the namespace to create
 * @return the Kubernetes manifest for the namespace
 */
export declare function createNamespace(cluster: ICluster, namespace: string): KubernetesManifest;
