import { IGatewayVpcEndpoint, IVpc } from 'aws-cdk-lib/aws-ec2';
import { IRole } from 'aws-cdk-lib/aws-iam';
import { IKey } from 'aws-cdk-lib/aws-kms';
import { ILogGroup } from 'aws-cdk-lib/aws-logs';
import { Construct } from 'constructs';
import { DataVpcProps } from './data-vpc-props';
/**
 * Creates a VPC with best practices for securely deploying data solutions.
 * @see https://awslabs.github.io/data-solutions-framework-on-aws/docs/constructs/library/Utils/data-vpc
 *
 * @example
 *
 * const vpc = new dsf.utils.DataVpc(this, 'DataVpc', {
 *   vpcCidr: '10.0.0.0/16',
 * });
 *
 * vpc.tagVpc('Name', 'My VPC');
 */
export declare class DataVpc extends Construct {
    /**
     * The amazon VPC created
     */
    readonly vpc: IVpc;
    /**
     * The KMS Key used to encrypt VPC flow logs
     */
    readonly flowLogKey: IKey;
    /**
     * The IAM role used to publish VPC Flow Logs
     */
    readonly flowLogRole: IRole;
    /**
     * The CloudWatch Log Group created for the VPC flow logs
     */
    readonly flowLogGroup: ILogGroup;
    /**
     * The S3 VPC endpoint gateway
     */
    readonly s3VpcEndpoint: IGatewayVpcEndpoint;
    constructor(scope: Construct, id: string, props: DataVpcProps);
    /**
     * Tag the VPC and the subnets
     * @param key the tag key
     * @param value the tag value
     */
    tagVpc(key: string, value: string): void;
}
